#include "ServerCell.h"

#include <qpixmap.h>

ServerCell::ServerCell(ServerType type)
	: ConnectorCell(), type(type), dirLock(false), paintLock(false)
{
}

ServerCell::ServerType
ServerCell::getServerType() const
{
	return type;
}

void
ServerCell::setDirection(Direction dir)
{
	if (getBoard() == NULL)
	{
		ConnectorCell::setDirection(dir);
		return;
	}

	if (dirLock)
		return;

	dirLock = true;

	Cell *cell = getBoard()->getNearCell(this,
		(getServerType() == SERVER_TOP ? SOUTH : NORTH));

	if (cell == NULL)
		return;

	cell->setDirection(dir);
	ConnectorCell::setDirection(dir);

	dirLock = false;
}

bool
ServerCell::isActive() const
{
	return true;
}

bool
ServerCell::hasConnector(Direction dir) const
{
	if ((getServerType() == SERVER_TOP    && dir != NORTH) ||
		(getServerType() == SERVER_BOTTOM && dir == NORTH))
	{
		return false;
	}

	return ConnectorCell::hasConnector(dir);
}

void
ServerCell::paint(QPainter &paint)
{
	static QPixmap *topPixmap = NULL, *bottomPixmap = NULL;

	if (paintLock)
		return;

	paintLock = true;

	ConnectorCell::paint(paint);

	Cell *cell = getBoard()->getNearCell(this,
		(getServerType() == SERVER_TOP ? SOUTH : NORTH));

	if (cell != NULL)
	{
		/* XXX Ugh, we have to manually transform this! :( */
		int thisX = getX() * Cell::WIDTH  + 1;
		int thisY = getY() * Cell::HEIGHT + 1;
		int cellX = cell->getX() * Cell::WIDTH  + 1;
		int cellY = cell->getY() * Cell::HEIGHT + 1;

		paint.translate(-thisX, -thisY);
		paint.translate(cellX, cellY);
		cell->paint(paint);
		paint.translate(-cellX, -cellY);
		paint.translate(thisX, thisY);
	}

	if (getServerType() == SERVER_TOP)
	{
		if (topPixmap == NULL)
		{
			topPixmap = new QPixmap();

			if (!topPixmap->load(DATA_PREFIX "images/server_top.png"))
				printf("Unable to load %s\n",
					   DATA_PREFIX "images/server_top.png");
		}

		paint.drawPixmap(0, 0, *topPixmap);
	}
	else
	{
		if (bottomPixmap == NULL)
		{
			bottomPixmap = new QPixmap();

			if (!bottomPixmap->load(DATA_PREFIX "images/server_bottom.png"))
				printf("Unable to load %s\n",
					   DATA_PREFIX "images/server_bottom.png");
		}

		paint.drawPixmap(0, 0, *bottomPixmap);
	}

	paintLock = false;
}

void
ServerCell::paintLine(QPainter &paint, Direction dir, bool d,
					  const QBrush &brush) const
{
	if ((getServerType() == SERVER_TOP &&
		 ((dir == SOUTH && !d) || dir == EAST || dir == WEST)) ||
		(getServerType() == SERVER_BOTTOM && (dir == NORTH && !d)))
	{
		return;
	}

	ConnectorCell::paintLine(paint, dir, d, brush);
}
