#include "Tickypip.h"

#include <qlayout.h>
#include <qmessagebox.h>
#include <qpushbutton.h>

Tickypip::Tickypip(QWidget *parent, const char *name, WFlags fl)
	: QWidget(parent, name, fl)
{
	setCaption("Tickypip");

	/* Setup the initial border layout. */
	BorderLayout *l = new BorderLayout(this, 0, -1, "borderlayout");

	/* Add the north layout. */
	QBoxLayout *north = new QHBoxLayout(NULL, 5, -1, "north-hbox");
	l->add(north, BorderLayout::North);

	/* Add the "Level Packs" button. */
	QPushButton *button = new QPushButton("Level Packs", this);
	north->addWidget(button, 1, Qt::AlignLeft);

	connect(button, SIGNAL(clicked()),
			this, SLOT(selectLevelPack()));

	/* Add the level drop-down. */
	levelsCombo = new QComboBox(FALSE, this);
	north->addWidget(levelsCombo, 0, Qt::AlignRight);

	connect(levelsCombo, SIGNAL(activated(int)),
			this, SLOT(levelChanged(int)));

	/* Add the center layout. */
	QBoxLayout *center = new QVBoxLayout(NULL, 0, -1, "center-vbox");
	l->add(center, BorderLayout::Center);

	/* Add the board. */
	board = new QTPBoard(this, NULL, this);
	center->addWidget(board, Qt::AlignCenter);

	/* Add the south layout. */
	QBoxLayout *south = new QHBoxLayout(NULL, 5, -1, "south-hbox");
	south->insertSpacing(0, 20);
	l->add(south, BorderLayout::South);

	/* Add the "Moves:" label. */
	QLabel *label = new QLabel("Moves:", this);
	south->addWidget(label, 0, Qt::AlignRight);

	/* Add the moves counter label. */
	movesLabel = new QLabel("0", this);
	south->addWidget(movesLabel);

	south->activate();

	l->activate();

	/* Pop up the levels dialog */
	if (!selectLevelPack())
		exit(0);
}

Tickypip::~Tickypip()
{
	delete levelsCombo;
	delete movesLabel;
	delete board;
}

void
Tickypip::reset()
{
	Level *level;

	movesLabel->setText("0");
	levelsCombo->clear();

	level = board->getBoard()->getLevel();

	if (level != NULL)
	{
		for (size_t i = 0; i < level->getNumLevels(); i++)
		{
			levelsCombo->insertItem("Level " + QString::number(i + 1));
		}
	}
}

void
Tickypip::levelCompleted()
{
	QString message = "Level completed in ";
	message = message + movesLabel->text() + " moves!";

	int curLevel = levelsCombo->currentItem();

	if (curLevel + 1 == (int)board->getBoard()->getLevel()->getNumLevels())
	{
		QMessageBox::information(this, "Tickypip", message, "New Level Pack");

		selectLevelPack();
	}
	else
	{
		QMessageBox::information(this, "Tickypip", message, "Next Level");

		levelChanged(levelsCombo->currentItem() + 1);
	}
}

void
Tickypip::incMovesCount()
{
	movesLabel->setText(QString::number(movesLabel->text().toInt() + 1));
}

bool
Tickypip::selectLevelPack()
{
	LevelsDialog levelsDialog(this);
	int r = levelsDialog.exec();

	if (r)
	{
		QString filename = levelsDialog.getSelectedFilename();

		if (filename == "")
			return false;

		board->loadLevel(DATA_PREFIX "levels/" + filename, 0);

		return true;
	}

	return false;
}

void
Tickypip::levelChanged(int level)
{
	levelsCombo->setCurrentItem(level);
	movesLabel->setText("0");
	board->getBoard()->getLevel()->setupLevel(level);
	board->repaint();
}
